@@ -80,8 +80,13 @@ parser = optparse.OptionParser(usage='Usage: %prog [FILE(s)]')
 prefs.setCmdLine(parser.parse_args())
 
 # PyGTK initialization
-gtk.window_set_default_icon(gtk.gdk.pixbuf_new_from_file(consts.fileImgIcon))
 gobject.threads_init()
+gtk.window_set_default_icon_list(gtk.gdk.pixbuf_new_from_file(consts.fileImgIcon16),
+                                 gtk.gdk.pixbuf_new_from_file(consts.fileImgIcon24),
+                                 gtk.gdk.pixbuf_new_from_file(consts.fileImgIcon32),
+                                 gtk.gdk.pixbuf_new_from_file(consts.fileImgIcon48),
+                                 gtk.gdk.pixbuf_new_from_file(consts.fileImgIcon64),
+                                 gtk.gdk.pixbuf_new_from_file(consts.fileImgIcon128))
 
 # Create the GUI
 wTree  = loadGladeFile('MainWindow.glade')
