@@ -45,11 +45,12 @@ def show(parent):
         '',
         _('Thanks to:'),
         ' * Emilio Pozuelo Monfort <pochu@ubuntu.com>',
+        ' * Matti Mårds <mamaar@gmail.com>',
         ' * The CrystalXP forum crew',
     ])
 
     # Set logo
-    dlg.set_logo(gtk.gdk.pixbuf_new_from_file(consts.fileImgAbout))
+    dlg.set_logo(gtk.gdk.pixbuf_new_from_file(consts.fileImgIcon128))
 
     # Load the licence from the disk if possible
     if os.path.isfile(consts.fileLicense) :
