@@ -19,7 +19,7 @@
 import asf, flac, mp3, mp4, mpc, ogg, os, playlist, tools, traceback
 
 from tools.log    import logger
-from tools.consts import UNKNOWN_TRACKNUMBER, UNKNOWN_TITLE, UNKNOWN_ARTIST, UNKNOWN_ALBUM, UNKNOWN_LENGTH
+from tools.consts import UNKNOWN_TRACKNUMBER, UNKNOWN_TITLE, UNKNOWN_ARTIST, UNKNOWN_ALBUM, UNKNOWN_LENGTH, UNKNOWN_ALBUM_ARTIST
 
 
 # The format of the list returned by the readInfo() and getTracks() functions
@@ -29,8 +29,9 @@ from tools.consts import UNKNOWN_TRACKNUMBER, UNKNOWN_TITLE, UNKNOWN_ARTIST, UNK
     NFO_ART,  # Artist
     NFO_ALB,  # Album
     NFO_LEN,  # Length in seconds
-    NFO_FIL   # Full path to the file
-) = range(6)
+    NFO_FIL,  # Full path to the file
+    NFO_AAR   # Album artist
+) = range(7)
 
 
 # Supported formats with associated modules
@@ -50,7 +51,7 @@ def getSupportedFormats():
 def readInfo(files):
     """
         Given a list of files, return a list such as:
-        [[TRACKNUMBER1, TITLE1, ARTIST1, ALBUM1, LENGTH1, FILE1], [TRACKNUMBER2, TITLE2, ARTIST2, ALBUM2, LENGTH2, FILE2], ...]
+        [[TRACKNUMBER1, TITLE1, ARTIST1, ALBUM1, LENGTH1, FILE1, ALBART1], [TRACKNUMBER2, TITLE2, ARTIST2, ALBUM2, LENGTH2, FILE2, ALBART2], ...]
     """
     info = []
     for file in files:
@@ -59,7 +60,7 @@ def readInfo(files):
             info.append(module.readInfo(file))
         except:
             logger.error('Unable to extract information from %s\n\n%s' % (file, traceback.format_exc()))
-            info.append([UNKNOWN_TRACKNUMBER, UNKNOWN_TITLE, UNKNOWN_ARTIST, UNKNOWN_ALBUM, UNKNOWN_LENGTH, file])
+            info.append([UNKNOWN_TRACKNUMBER, UNKNOWN_TITLE, UNKNOWN_ARTIST, UNKNOWN_ALBUM, UNKNOWN_LENGTH, file, UNKNOWN_ALBUM_ARTIST])
 
     return info
 
