@@ -26,7 +26,7 @@ def readInfo(file):
     """ Read information from a Flac file """
     flacFile = FLAC(file)
 
-    info = [consts.UNKNOWN_TRACKNUMBER, consts.UNKNOWN_TITLE, consts.UNKNOWN_ARTIST, consts.UNKNOWN_ALBUM, int(round(flacFile.info.length)), file]
+    info = [consts.UNKNOWN_TRACKNUMBER, consts.UNKNOWN_TITLE, consts.UNKNOWN_ARTIST, consts.UNKNOWN_ALBUM, int(round(flacFile.info.length)), file, consts.UNKNOWN_ALBUM_ARTIST]
 
     try:    info[media.NFO_TIT] = flacFile['title'][0]
     except: pass
@@ -37,6 +37,9 @@ def readInfo(file):
     try:    info[media.NFO_ART] = flacFile['artist'][0]
     except: pass
 
+    try:    info[media.NFO_AAR] = flacFile['albumartist'][0]
+    except: pass
+
     try:    info[media.NFO_NUM] = int(str(flacFile['tracknumber'][0]).split('/')[0])  # Track format may be 01/08, 02/08...
     except: pass
 
