@@ -28,7 +28,7 @@ def readInfo(file):
     id3     = ID3(file)
     mp3File = MP3(file)
 
-    info = [consts.UNKNOWN_TRACKNUMBER, consts.UNKNOWN_TITLE, consts.UNKNOWN_ARTIST, consts.UNKNOWN_ALBUM, int(round(mp3File.info.length)), file]
+    info = [consts.UNKNOWN_TRACKNUMBER, consts.UNKNOWN_TITLE, consts.UNKNOWN_ARTIST, consts.UNKNOWN_ALBUM, int(round(mp3File.info.length)), file, consts.UNKNOWN_ALBUM_ARTIST]
 
     try:    info[media.NFO_TIT] = unicode(str(id3['TIT2']), errors='replace')
     except: pass
@@ -39,6 +39,9 @@ def readInfo(file):
     try:    info[media.NFO_ART] = unicode(str(id3['TPE1']), errors='replace')
     except: pass
 
+    try:    info[media.NFO_AAR] = unicode(str(id3['TPE2']), errors='replace')
+    except: pass
+
     try:    info[media.NFO_NUM] = int(str(id3['TRCK']).split('/')[0])  # Track format may be 01/08, 02/08...
     except: pass
 
