@@ -26,7 +26,7 @@ def readInfo(file):
     """ Read information from an Ogg Vorbis file """
     oggFile = OggVorbis(file)
 
-    info = [consts.UNKNOWN_TRACKNUMBER, consts.UNKNOWN_TITLE, consts.UNKNOWN_ARTIST, consts.UNKNOWN_ALBUM, int(round(oggFile.info.length)), file]
+    info = [consts.UNKNOWN_TRACKNUMBER, consts.UNKNOWN_TITLE, consts.UNKNOWN_ARTIST, consts.UNKNOWN_ALBUM, int(round(oggFile.info.length)), file, consts.UNKNOWN_ALBUM_ARTIST]
 
     try:    info[media.NFO_TIT] = oggFile['title'][0]
     except: pass
@@ -37,6 +37,9 @@ def readInfo(file):
     try:    info[media.NFO_ART] = oggFile['artist'][0]
     except: pass
 
+    try:    info[media.NFO_AAR] = oggFile['albumartist'][0]
+    except: pass
+
     try:    info[media.NFO_NUM] = int(str(oggFile['tracknumber'][0]).split('/')[0])  # Track format may be 01/08, 02/08...
     except: pass
 
