@@ -50,14 +50,15 @@ class Track:
 
     def __init__(self, (number, title, artist, album, length, path), plPos, plLen):
         """ Constructor """
-        self.path   = path
-        self.plPos  = plPos
-        self.plLen  = plLen
-        self.title  = title
-        self.album  = album
-        self.artist = artist
-        self.length = length
-        self.number = number
+        self.path        = path
+        self.plPos       = plPos
+        self.plLen       = plLen
+        self.title       = title
+        self.album       = album
+        self.artist      = artist
+        self.length      = length
+        self.number      = number
+        self.albumartist = consts.UNKNOWN_ALBUM_ARTIST
 
 
     def hasTitle(self):  return self.title  != consts.UNKNOWN_TITLE
@@ -78,7 +79,7 @@ class Track:
 
     def getFields(self):
         """ Return a list with all the fields (same format used by media.readInfo) """
-        return [self.number, self.title, self.artist, self.album, self.length, self.path]
+        return [self.number, self.title, self.artist, self.album, self.length, self.path, self.albumartist]
 
 
     def getLengthSec(self):
