@@ -23,6 +23,8 @@ from gettext import gettext as _
 
 MOD_INFO = ('Control Panel', 'Control Panel', '', [], True, False)
 
+PREFS_DEFAULT_VOLUME = 0.65
+
 
 class CtrlPanel(modules.Module):
     """ This module manages the control panel with the buttons and the slider """
@@ -31,7 +33,8 @@ class CtrlPanel(modules.Module):
         """ Constructor """
         modules.Module.__init__(self, (consts.MSG_EVT_STOPPED,        consts.MSG_EVT_PAUSED,      consts.MSG_EVT_UNPAUSED,
                                        consts.MSG_EVT_TRACK_MOVED,    consts.MSG_EVT_NEW_TRACK,   consts.MSG_EVT_NEW_TRACKLIST,
-                                       consts.MSG_EVT_TRACK_POSITION, consts.MSG_EVT_APP_STARTED))
+                                       consts.MSG_EVT_TRACK_POSITION, consts.MSG_EVT_APP_STARTED, consts.MSG_EVT_APP_QUIT,
+                                       consts.MSG_EVT_VOLUME_CHANGED))
 
 
     def onAppStarted(self):
@@ -45,20 +48,27 @@ class CtrlPanel(modules.Module):
         self.btnNext      = wTree.get_widget('btn-next')
         self.btnPrev      = wTree.get_widget('btn-previous')
         self.sclSeek      = wTree.get_widget('scl-position')
+        self.btnVolume    = gtk.VolumeButton()
         self.lblElapsed   = wTree.get_widget('lbl-elapsedTime')
         self.lblRemaining = wTree.get_widget('lbl-remainingTime')
 
+        wTree.get_widget('box-ctrl-buttons').pack_end(self.btnVolume, False)
+        self.btnVolume.set_relief(gtk.RELIEF_NORMAL)
+        self.btnVolume.show()
         # Initial state
         self.onStopped()
         self.btnPlay.set_sensitive(False)
         # GTK handlers
-        self.btnStop.connect('clicked',      lambda widget: modules.postMsg(consts.MSG_CMD_STOP))
-        self.btnNext.connect('clicked',      lambda widget: modules.postMsg(consts.MSG_CMD_NEXT))
-        self.btnPrev.connect('clicked',      lambda widget: modules.postMsg(consts.MSG_CMD_PREVIOUS))
-        self.btnPlay.connect('clicked',      lambda widget: modules.postMsg(consts.MSG_CMD_TOGGLE_PAUSE))
-        self.sclSeek.connect('change-value', self.onSeekChangeValue)
+        self.btnStop.connect('clicked',         lambda widget: modules.postMsg(consts.MSG_CMD_STOP))
+        self.btnNext.connect('clicked',         lambda widget: modules.postMsg(consts.MSG_CMD_NEXT))
+        self.btnPrev.connect('clicked',         lambda widget: modules.postMsg(consts.MSG_CMD_PREVIOUS))
+        self.btnPlay.connect('clicked',         lambda widget: modules.postMsg(consts.MSG_CMD_TOGGLE_PAUSE))
+        self.sclSeek.connect('change-value',    self.onSeekChangeValue)
         # We need to keep the handler ID for this one to be able to disconnect it when needed
         self.seekHandler   = self.sclSeek.connect('value-changed',   self.onSeekValueChanged)
+        self.volumeHandler = self.btnVolume.connect('value-changed', self.onVolumeValueChanged)
+        # This must be done only when the handler has been connected
+        self.btnVolume.set_value(prefs.get(__name__, 'volume', PREFS_DEFAULT_VOLUME))
 
 
     def onNewTrack(self, track):
@@ -100,6 +110,13 @@ class CtrlPanel(modules.Module):
             self.seekHandler = self.sclSeek.connect('value-changed', self.onSeekValueChanged)
 
 
+    def onVolumeChanged(self, value):
+        """ The volume has been changed """
+        self.btnVolume.disconnect(self.volumeHandler)
+        self.btnVolume.set_value(value)
+        self.volumeHandler = self.btnVolume.connect('value-changed', self.onVolumeValueChanged)
+
+
     def onTrackMoved(self, hasPrevious, hasNext):
         """ Update previous and next buttons """
         self.btnNext.set_sensitive(hasNext)
@@ -138,6 +155,11 @@ class CtrlPanel(modules.Module):
         self.lblRemaining.set_label(tools.sec2str(self.currTrackLength - value))
 
 
+    def onVolumeValueChanged(self, button, value):
+        """ The user has moved the volume slider """
+        modules.postMsg(consts.MSG_CMD_SET_VOLUME, {'value': value})
+
+
    # --== Message handler ==--
 
 
@@ -146,8 +168,10 @@ class CtrlPanel(modules.Module):
         if   msg == consts.MSG_EVT_PAUSED:         self.onPaused()
         elif msg == consts.MSG_EVT_STOPPED:        self.onStopped()
         elif msg == consts.MSG_EVT_UNPAUSED:       self.onUnpaused()
+        elif msg == consts.MSG_EVT_APP_QUIT:       prefs.set(__name__, 'volume', self.btnVolume.get_value())
         elif msg == consts.MSG_EVT_NEW_TRACK:      self.onNewTrack(params['track'])
         elif msg == consts.MSG_EVT_APP_STARTED:    self.onAppStarted()
         elif msg == consts.MSG_EVT_TRACK_MOVED:    self.onTrackMoved(params['hasPrevious'], params['hasNext'])
         elif msg == consts.MSG_EVT_NEW_TRACKLIST:  self.btnPlay.set_sensitive(len(params['tracks']) != 0)
         elif msg == consts.MSG_EVT_TRACK_POSITION: self.onNewTrackPosition(params['seconds'])
+        elif msg == consts.MSG_EVT_VOLUME_CHANGED: self.onVolumeChanged(params['value'])
