@@ -28,7 +28,7 @@ MOD_L10N = MOD_INFO[modules.MODINFO_L10N]
 
 # Default preferences
 PREFS_DEFAULT_BODY       = 'by {artist}\nfrom {album}\n\nTrack {playlist_pos} out of {playlist_len}'
-PREFS_DEFAULT_TITLE      = '<b>{title}</b>  [{duration_str}]'
+PREFS_DEFAULT_TITLE      = '{title}  [{duration_str}]'
 PREFS_DEFAULT_TIMEOUT    = 10
 PREFS_DEFAULT_SKIP_TRACK = True
 
@@ -63,8 +63,8 @@ class DesktopNotification(modules.ThreadedModule):
 
     def showNotification(self, track):
         """ Show the notification based on the given track """
-        body  = track.formatHTMLSafe(prefs.get(__name__, 'body', PREFS_DEFAULT_BODY))
-        title = '<span weight="normal">%s</span>' % track.formatHTMLSafe(prefs.get(__name__, 'title', PREFS_DEFAULT_TITLE))
+        body  = track.formatHTMLSafe(prefs.get(__name__, 'body',  PREFS_DEFAULT_BODY))
+        title = track.formatHTMLSafe(prefs.get(__name__, 'title', PREFS_DEFAULT_TITLE))
 
         # Make sure the notification exists
         if self.notif is None:
