@@ -112,8 +112,11 @@ class Explorer(modules.Module):
             self.store.append(row)
 
         # Restore the previously selected index, if any
-        if newIndex == -1: self.notebook.set_current_page(0)
-        else:              self.combo.set_active(newIndex)
+        if newIndex == -1:
+            self.notebook.set_current_page(0)
+            self.currExplorer = -1
+        else:
+            self.combo.set_active(newIndex)
 
         self.combo.set_sensitive(len(self.store) != 0)
         self.combo.thaw_child_notify()
