@@ -167,6 +167,11 @@ class FileExplorer(modules.Module):
 
     def exploreDir(self, tree, parent, directory):
         """ List the content of the given directory and append it to the tree as a child of parent """
+
+        # Make sure the durectory is still there
+        if not os.path.exists(directory):
+            return
+
         directories, playlists, mediaFiles = self.getDirContent(directory)
 
         tree.appendRows(directories, parent)
