@@ -206,6 +206,9 @@ class Library(modules.Module):
         for track in mediaFiles:
             album, artist = track[media.NFO_ALB], track[media.NFO_ART]
 
+            if len(track) > 6 and track[media.NFO_AAR] != consts.UNKNOWN_ALBUM_ARTIST:
+                artist = track[media.NFO_AAR]
+
             if artist in db:
                 allAlbums = db[artist]
                 if album in allAlbums: allAlbums[album].append(track)
