@@ -64,10 +64,10 @@ class StatusIcon(modules.Module):
     def renderIcons(self, statusIcon, availableSize):
         """ (Re) Create icons based the available tray size """
         # Normal icon
-        if   availableSize >= 48+2: self.icoNormal = gtk.gdk.pixbuf_new_from_file(os.path.join(consts.dirPix, 'decibel-audio-player.png'))
-        elif availableSize >= 32+2: self.icoNormal = gtk.gdk.pixbuf_new_from_file(os.path.join(consts.dirPix, 'decibel-audio-player-32.png'))
-        elif availableSize >= 24+2: self.icoNormal = gtk.gdk.pixbuf_new_from_file(os.path.join(consts.dirPix, 'decibel-audio-player-24.png'))
-        else:                       self.icoNormal = gtk.gdk.pixbuf_new_from_file(os.path.join(consts.dirPix, 'decibel-audio-player-16.png'))
+        if   availableSize >= 48+2: self.icoNormal = gtk.gdk.pixbuf_new_from_file(consts.fileImgIcon48)
+        elif availableSize >= 32+2: self.icoNormal = gtk.gdk.pixbuf_new_from_file(consts.fileImgIcon32)
+        elif availableSize >= 24+2: self.icoNormal = gtk.gdk.pixbuf_new_from_file(consts.fileImgIcon24)
+        else:                       self.icoNormal = gtk.gdk.pixbuf_new_from_file(consts.fileImgIcon16)
 
         # Paused icon
         self.icoPause = gtk.gdk.Pixbuf(gtk.gdk.COLORSPACE_RGB, True, 8, self.icoNormal.get_width(), self.icoNormal.get_height())
