@@ -143,10 +143,10 @@ class Tracklist(modules.Module):
             Refer to set() for the meaning of readTags
         """
         if not readTags:
-            tracks = [[consts.icoNull] + track for track in tracks]
+            tracks = [[consts.icoNull] + track[0:6] for track in tracks]                    # Remove "album artist", we don't use it
         else:
             files  = [track[7:] for track in tracks if track.startswith('file://')]
-            tracks = [[consts.icoNull] + track for track in media.getTracks(files)]
+            tracks = [[consts.icoNull] + track[0:6] for track in media.getTracks(files)]    # Remove "album artist", we don't use it
 
             for track in tracks:
                 track[ROW_PTH] = 'file://' + track[ROW_PTH]
