@@ -33,7 +33,7 @@ socketTimeout = 10
 
 # --- Strings
 appName      = 'Decibel Audio Player'
-appVersion   = '0.09'
+appVersion   = '0.10'
 appNameShort = 'decibel-audio-player'
 
 
@@ -73,12 +73,19 @@ if not os.path.exists(dirCfg):
 if not os.path.exists(dirLog): os.mkdir(dirLog)
 
 
+# --- Icons
+fileImgIcon16  = os.path.join(dirPix, 'decibel-audio-player-16.png')
+fileImgIcon24  = os.path.join(dirPix, 'decibel-audio-player-24.png')
+fileImgIcon32  = os.path.join(dirPix, 'decibel-audio-player-32.png')
+fileImgIcon48  = os.path.join(dirPix, 'decibel-audio-player.png')
+fileImgIcon64  = os.path.join(dirPix, 'decibel-audio-player-64.png')
+fileImgIcon128 = os.path.join(dirPix, 'decibel-audio-player-128.png')
+
+
 # --- Files
 fileLog        = os.path.join(dirLog, 'log')
 filePrefs      = os.path.join(dirCfg, 'prefs.txt')
 fileLicense    = os.path.join(dirDoc, 'LICENCE')
-fileImgIcon    = os.path.join(dirPix, 'decibel-audio-player-16.png')
-fileImgAbout   = os.path.join(dirPix, 'decibel-audio-player-128.png')
 fileImgRepeat  = __sureFile('/usr/share/icons/gnome/22x22/status/media-playlist-repeat.png')
 fileImgShuffle = __sureFile('/usr/share/icons/gnome/22x22/status/media-playlist-shuffle.png')
 
@@ -90,11 +97,12 @@ dbusInterface = 'org.silentblade.decibel.remoteinterface'
 
 
 # --- Tracks
-UNKNOWN_TITLE       = _('Unknown title')
-UNKNOWN_ALBUM       = _('Unknown Album')
-UNKNOWN_ARTIST      = _('Unknown Artist')
-UNKNOWN_LENGTH      = 0
-UNKNOWN_TRACKNUMBER = 0
+UNKNOWN_TITLE        = _('Unknown title')
+UNKNOWN_ALBUM        = _('Unknown Album')
+UNKNOWN_ARTIST       = _('Unknown Artist')
+UNKNOWN_LENGTH       = 0
+UNKNOWN_TRACKNUMBER  = 0
+UNKNOWN_ALBUM_ARTIST = ''
 
 
 # --- Stock icons
